==> huaweicloudsdkiam-3.1.134-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/show_domain_role_assignments_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDomainRoleAssignmentsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_num': 'int',
        'role_assignments': 'list[RoleAssignmentBody]'
    }

    attribute_map = {
        'total_num': 'total_num',
        'role_assignments': 'role_assignments'
    }

    def __init__(self, total_num=None, role_assignments=None):
        """ShowDomainRoleAssignmentsResponse

        The model defined in huaweicloud sdk

        :param total_num: 返回授权记录的总条数。
        :type total_num: int
        :param role_assignments: 
        :type role_assignments: list[:class:`huaweicloudsdkiam.v3.RoleAssignmentBody`]
        """
        
        super(ShowDomainRoleAssignmentsResponse, self).__init__()

        self._total_num = None
        self._role_assignments = None
        self.discriminator = None

        if total_num is not None:
            self.total_num = total_num
        if role_assignments is not None:
            self.role_assignments = role_assignments

    @property
    def total_num(self):
        """Gets the total_num of this ShowDomainRoleAssignmentsResponse.

        返回授权记录的总条数。

        :return: The total_num of this ShowDomainRoleAssignmentsResponse.
        :rtype: int
        """
        return self._total_num

    @total_num.setter
    def total_num(self, total_num):
        """Sets the total_num of this ShowDomainRoleAssignmentsResponse.

        返回授权记录的总条数。

        :param total_num: The total_num of this ShowDomainRoleAssignmentsResponse.
        :type total_num: int
        """
        self._total_num = total_num

    @property
    def role_assignments(self):
        """Gets the role_assignments of this ShowDomainRoleAssignmentsResponse.

        :return: The role_assignments of this ShowDomainRoleAssignmentsResponse.
        :rtype: list[:class:`huaweicloudsdkiam.v3.RoleAssignmentBody`]
        """
        return self._role_assignments

    @role_assignments.setter
    def role_assignments(self, role_assignments):
        """Sets the role_assignments of this ShowDomainRoleAssignmentsResponse.

        :param role_assignments: The role_assignments of this ShowDomainRoleAssignmentsResponse.
        :type role_assignments: list[:class:`huaweicloudsdkiam.v3.RoleAssignmentBody`]
        """
        self._role_assignments = role_assignments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainRoleAssignmentsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.1.152-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/show_domain_role_assignments_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDomainRoleAssignmentsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_num': 'int',
        'role_assignments': 'list[RoleAssignmentBody]'
    }

    attribute_map = {
        'total_num': 'total_num',
        'role_assignments': 'role_assignments'
    }

    def __init__(self, total_num=None, role_assignments=None):
        r"""ShowDomainRoleAssignmentsResponse

        The model defined in huaweicloud sdk

        :param total_num: 返回授权记录的总条数。
        :type total_num: int
        :param role_assignments: 
        :type role_assignments: list[:class:`huaweicloudsdkiam.v3.RoleAssignmentBody`]
        """
        
        super(ShowDomainRoleAssignmentsResponse, self).__init__()

        self._total_num = None
        self._role_assignments = None
        self.discriminator = None

        if total_num is not None:
            self.total_num = total_num
        if role_assignments is not None:
            self.role_assignments = role_assignments

    @property
    def total_num(self):
        r"""Gets the total_num of this ShowDomainRoleAssignmentsResponse.

        返回授权记录的总条数。

        :return: The total_num of this ShowDomainRoleAssignmentsResponse.
        :rtype: int
        """
        return self._total_num

    @total_num.setter
    def total_num(self, total_num):
        r"""Sets the total_num of this ShowDomainRoleAssignmentsResponse.

        返回授权记录的总条数。

        :param total_num: The total_num of this ShowDomainRoleAssignmentsResponse.
        :type total_num: int
        """
        self._total_num = total_num

    @property
    def role_assignments(self):
        r"""Gets the role_assignments of this ShowDomainRoleAssignmentsResponse.

        :return: The role_assignments of this ShowDomainRoleAssignmentsResponse.
        :rtype: list[:class:`huaweicloudsdkiam.v3.RoleAssignmentBody`]
        """
        return self._role_assignments

    @role_assignments.setter
    def role_assignments(self, role_assignments):
        r"""Sets the role_assignments of this ShowDomainRoleAssignmentsResponse.

        :param role_assignments: The role_assignments of this ShowDomainRoleAssignmentsResponse.
        :type role_assignments: list[:class:`huaweicloudsdkiam.v3.RoleAssignmentBody`]
        """
        self._role_assignments = role_assignments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainRoleAssignmentsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
